@@ -5,7 +5,7 @@ use strict;
 use 5.008003;
 no warnings 'utf8';
 
-our $VERSION = '1.053';
+our $VERSION = '1.054';
 
 use Encode                qw( decode );
 use File::Basename        qw( basename );
@@ -626,17 +626,12 @@ App::DBBrowser - Browse SQLite/MySQL/PostgreSQL databases and their tables inter
 
 =head1 VERSION
 
-Version 1.053
+Version 1.054
 
 =head1 DESCRIPTION
 
 See L<db-browser> for further information.
 
-=head1 CREDITS
-
-Thanks to the L<Perl-Community.de|http://www.perl-community.de> and the people form
-L<stackoverflow|http://stackoverflow.com> for the help.
-
 =head1 AUTHOR
 
 Matthäus Kiem <cuer2s@gmail.com>
