@@ -6,7 +6,7 @@ use strict;
 use 5.008003;
 no warnings 'utf8';
 
-our $VERSION = '1.053';
+our $VERSION = '1.054';
 
 
 
@@ -16,7 +16,7 @@ App::DBBrowser::DB - Database plugin documentation.
 
 =head1 VERSION
 
-Version 1.053
+Version 1.054
 
 
 =head1 DESCRIPTION
@@ -894,18 +894,13 @@ __END__
 
 =encoding UTF-8
 
-=head1 CREDITS
-
-Thanks to the L<Perl-Community.de|http://www.perl-community.de> and the people form
-L<stackoverflow|http://stackoverflow.com> for the help.
-
 =head1 AUTHOR
 
 Matthäus Kiem <cuer2s@gmail.com>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2012-2017 Matthäus Kiem.
+Copyright 2012-2018 Matthäus Kiem.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl 5.10.0. For
 details, see the full text of the licenses in the file LICENSE.
